@@ -14,11 +14,6 @@ test_that("get_lyrics_id returns the right output formats", {
   expect_is(output, "data.frame")
   expect_setequal(output$song_id, id)
 
-  output <- scrape_lyrics_id(song_id = id)
-  expect_is(output, "tbl_df")
-  expect_is(output, "tbl")
-  expect_is(output, "data.frame")
-  expect_setequal(output$song_id, id)
 })
 
 test_that("get_lyrics_url returns the right output formats", {
@@ -32,11 +27,6 @@ test_that("get_lyrics_url returns the right output formats", {
   expect_is(output, "data.frame")
   expect_setequal(output$song_lyrics_url, url)
 
-  output <- scrape_lyrics_url(song_lyrics_url = "https://genius.com/Kendrick-lamar-dna-lyrics")
-  expect_is(output, "tbl_df")
-  expect_is(output, "tbl")
-  expect_is(output, "data.frame")
-  expect_setequal(output$song_lyrics_url, url)
 })
 
 test_that("get_lyrics_search returns the right output formats", {
